==> piwigo-11.5.0.zip: piwigo/language/tr_TR/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Installation'] = 'Yükleme';
$lang['Basic configuration'] = 'Temel yapılandırma';
$lang['Default gallery language'] = 'Varsayılan galeri dili';
$lang['Database configuration'] = 'Veritabanı yapılandırması';
$lang['Admin configuration'] = 'Yönetici yapılandırması';
$lang['Start Install'] = 'Yüklemeyi başlat';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Bu ziyaretçilere gösterilecek. Bu web sitesi yönetimi için gereklidir';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Sunucuya bağlantı başarılı ancak veritabanı bağlantısı kurulamadı.';
$lang['Can\'t connect to server'] = 'Sunucuya bağlanamadı';
$lang['Host'] = 'Sunucu';
$lang['User'] = 'Kullanıcı';
$lang['user login given by your host provider'] = 'barındırma sağlağıcı tarafından size verilen kullanıcı adı';
$lang['user password given by your host provider'] = 'barındırma sağlağıcı tarafından size verilen şifre';
$lang['Database name'] = 'Veritabanı adı';
$lang['also given by your host provider'] = 'ayrıca barındırma sağlayıcınız tarafından verilen';
$lang['Database table prefix'] = 'Veritabanı tabloları öneki';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'veritabanı tablo isimlerinin önüne bu öntakı eklenecektir (tablolarınızı daha iyi yönetmenizi sağlar)';
$lang['enter a login for webmaster'] = 'Site yöneticisi için bir kullanıcı adı girin';
$lang['webmaster login can\'t contain characters \' or "'] = 'Site yöneticisi adı \' veya " karakterlerini içeremez';
$lang['please enter your password again'] = 'lütfen şifrenizi tekrar giriniz';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Gizli tutun, yönetim paneline ulaşmanızı sağlar';
$lang['Password [confirm]'] = 'Şifre [kabul]';
$lang['verification'] = 'doğrulama';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Yardım ihtiyacınız var? Sorularınızı <a href="%s">Piwigo forumda sorabilirsiniz</a>.';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Ziyaretçilerin site yöneticisi ile bağlantıya geçmesi için bu e-posta adresini kullanabileceklerdir.';
$lang['PHP 5 is required'] = 'PHP 5.2 gereklidir';
$lang['It appears your webhost is currently running PHP %s.'] = 'Web sunucunuz şu anda PHP %s çalıştırıyor görünüyor.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo .htaccess dosyası oluşturarak veya değiştirerek ayarlarınızı PHP 5.2 \'e geçirmeyi deneyebilir.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Not: Yapılandırmayı kendiniz değiştirip sonrasında Piwigo\'yu tekrar başlatabilirsiniz.';
$lang['Try to configure PHP 5'] = 'PHP 5.2 yapılandırmasını dene';
$lang['Sorry!'] = 'Üzgünüm!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo, PHP 5.2 yapılandırmasını başaramadı.';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Barındırma sağlayıcınızın desteğini alarak, kendinizin PHP 5.2\'e nasıl geçebileceğinizi öğrenin.';
$lang['Hope to see you back soon.'] = 'Yakında tekrar görüşmek dileğiyle.';
$lang['Congratulations, Piwigo installation is completed'] = 'Tebrikler, Piwigo kurulumu tamamlandı.';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Diğer çözüm aşağıdaki kutudaki yazıyı kopyalayın ve "local/config/database.inc.php" dosyası içine pasteleyin.(Uyarı : database.inc.php sadece yazı içermeli hiçbir ifade veya boşluk karakteri içermemelidir)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'ocal/config/database.inc.php konfigürasyon dosyasının oluşturulması başarısız oldu.';
$lang['Download the config file'] = 'Yapılandırma dosyasını indir';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Yapılandırma dosyasını indirip kurulum dizininde local/config bölümüne yükleyebilirsiniz.';
$lang['Just another Piwigo gallery'] = 'Bir başka Piwigo galerisi';
$lang['Welcome to my photo gallery'] = 'Fotoğraf galerime hoş geldiniz';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Herhangi bir sebeple yardım gerektiğinde, forumlarımıza danışmakta tereddüt etmeyin: %s';
$lang['Welcome to your new installation of Piwigo!'] = 'Piwigo\'nunuzun yeni kurulumuna hoşgeldiniz!';
$lang['Password ']['confirm'] = 'Şifre [doğrula]';
$lang['localhost or other, supplied by your host provider'] = 'localhost veya diğer, bulundurma hizmeti sağlayıcınız tarafından verilen';

==> piwigo-15.6.0.zip: piwigo/language/tr_TR/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Installation'] = 'Yükleme';
$lang['Basic configuration'] = 'Temel yapılandırma';
$lang['Default gallery language'] = 'Varsayılan galeri dili';
$lang['Database configuration'] = 'Veritabanı yapılandırması';
$lang['Admin configuration'] = 'Yönetici yapılandırması';
$lang['Start Install'] = 'Yüklemeyi başlat';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Bu ziyaretçilere gösterilecek. Bu web sitesi yönetimi için gereklidir';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Sunucuya bağlantı başarılı ancak veritabanı bağlantısı kurulamadı.';
$lang['Can\'t connect to server'] = 'Sunucuya bağlanamadı';
$lang['Host'] = 'Sunucu';
$lang['User'] = 'Kullanıcı';
$lang['user login given by your host provider'] = 'barındırma sağlağıcı tarafından size verilen kullanıcı adı';
$lang['user password given by your host provider'] = 'barındırma sağlağıcı tarafından size verilen şifre';
$lang['Database name'] = 'Veritabanı adı';
$lang['also given by your host provider'] = 'ayrıca barındırma sağlayıcınız tarafından verilen';
$lang['Database table prefix'] = 'Veritabanı tabloları öneki';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'veritabanı tablo isimlerinin önüne bu öntakı eklenecektir (tablolarınızı daha iyi yönetmenizi sağlar)';
$lang['enter a login for webmaster'] = 'Site yöneticisi için bir kullanıcı adı girin';
$lang['webmaster login can\'t contain characters \' or "'] = 'Site yöneticisi adı \' veya " karakterlerini içeremez';
$lang['please enter your password again'] = 'lütfen şifrenizi tekrar giriniz';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Gizli tutun, yönetim paneline ulaşmanızı sağlar';
$lang['Password [confirm]'] = 'Şifre [kabul]';
$lang['verification'] = 'doğrulama';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Yardım ihtiyacınız var? Sorularınızı <a href="%s">Piwigo forumda sorabilirsiniz</a>.';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Ziyaretçilerin site yöneticisi ile bağlantıya geçmesi için bu e-posta adresini kullanabileceklerdir.';
$lang['PHP 5 is required'] = 'PHP 5.2 gereklidir';
$lang['It appears your webhost is currently running PHP %s.'] = 'Web sunucunuz şu anda PHP %s çalıştırıyor görünüyor.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo .htaccess dosyası oluşturarak veya değiştirerek ayarlarınızı PHP 5.2 \'e geçirmeyi deneyebilir.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Not: Yapılandırmayı kendiniz değiştirip sonrasında Piwigo\'yu tekrar başlatabilirsiniz.';
$lang['Try to configure PHP 5'] = 'PHP 5.2 yapılandırmasını dene';
$lang['Sorry!'] = 'Üzgünüm!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo, PHP 5.2 yapılandırmasını başaramadı.';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Barındırma sağlayıcınızın desteğini alarak, kendinizin PHP 5.2\'e nasıl geçebileceğinizi öğrenin.';
$lang['Hope to see you back soon.'] = 'Yakında tekrar görüşmek dileğiyle.';
$lang['Congratulations, Piwigo installation is completed'] = 'Tebrikler, Piwigo kurulumu tamamlandı.';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Diğer çözüm aşağıdaki kutudaki yazıyı kopyalayın ve "local/config/database.inc.php" dosyası içine pasteleyin.(Uyarı : database.inc.php sadece yazı içermeli hiçbir ifade veya boşluk karakteri içermemelidir)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'ocal/config/database.inc.php konfigürasyon dosyasının oluşturulması başarısız oldu.';
$lang['Download the config file'] = 'Yapılandırma dosyasını indir';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Yapılandırma dosyasını indirip kurulum dizininde local/config bölümüne yükleyebilirsiniz.';
$lang['Just another Piwigo gallery'] = 'Bir başka Piwigo galerisi';
$lang['Welcome to my photo gallery'] = 'Fotoğraf galerime hoş geldiniz';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Herhangi bir sebeple yardım gerektiğinde, forumlarımıza danışmakta tereddüt etmeyin: %s';
$lang['Welcome to your new installation of Piwigo!'] = 'Piwigo\'nunuzun yeni kurulumuna hoşgeldiniz!';
$lang['Password ']['confirm'] = 'Şifre [doğrula]';
$lang['localhost or other, supplied by your host provider'] = 'localhost veya diğer, bulundurma hizmeti sağlayıcınız tarafından verilen';
$lang['PHP version %s required (you are running on PHP %s)'] = 'PHP %s sürümü gerekli (PHP %s üzerinde çalışıyorsunuz)';
